@@ -90,8 +90,13 @@ from Progress import GtkOpProgressWindow, GtkCdromProgress
 from Util import *
 from Cache import MyCache
 
-from Menu import SHOW_ALL, SHOW_ONLY_SUPPORTED, SHOW_ONLY_FREE, SHOW_ONLY_MAIN, SHOW_ONLY_PROPRIETARY, SHOW_ONLY_THIRD_PARTY, SHOW_ONLY_INSTALLED
-
+from Menu import (SHOW_ALL,
+                  SHOW_ONLY_SUPPORTED,
+                  SHOW_ONLY_FREE,
+                  SHOW_ONLY_MAIN,
+                  SHOW_ONLY_PROPRIETARY,
+                  SHOW_ONLY_THIRD_PARTY,
+                  SHOW_ONLY_INSTALLED)
 
 
 class AppInstallDbusControler(dbus.service.Object):
@@ -425,7 +430,7 @@ class AppInstall(SimpleGladeApp):
         self.tooltips.set_tip(self.eventbox_filter, tooltip)
         self.setBusy(False)
 
-    def refilter(self, filter=None, terms=None):
+    def refilter(self, filter=None, terms=None, model=None):
         """
         Applies the given filter or search terms to the menu filter and provides
         a visual feedback for empty results
@@ -434,7 +439,7 @@ class AppInstall(SimpleGladeApp):
             self.menu.filter = filter
         if terms != None:
             self.menu.searchTerms = terms
-        self.menu._refilter()
+        self.menu._refilter(model)
         if len(self.menu.treeview_packages.get_model()) == 0:
              self.show_no_results_msg()
              self.treeview_packages.set_sensitive(False)
@@ -675,7 +680,7 @@ class AppInstall(SimpleGladeApp):
                      "* These restrictions do not apply in your country "
                      "of legal residence\n"
                      "* You have permission to use this software (for "
-                     " example, a patent license)\n"
+                     "example, a patent license)\n"
                      "* You are using this software for research "
                      "purposes only")
             dia.set_markup("<big><b>%s</b></big>\n\n%s" % (header,body))
@@ -716,15 +721,15 @@ class AppInstall(SimpleGladeApp):
                 (primary, secondary) = messages[None]
                 primary = primary % item.component
         elif item.channel:
-            if item.vendor:
-                vendor = item.vendor
+            if item.isv:
+                vendor = item.isv
             else:
                 vendor = item.channel
             primary = _("Enable the installation of software "
                         "from %s?") % vendor
             secondary = _("%s is provided by a third party vendor. The third "
                           "party vendor is responsible for support and "
-                          "security updates.") % item.name
+                          "security updates.")
         if need_internet:
             secondary += "\n\n%s" % _("You need a working internet connection "
                                       "to continue.")
@@ -1120,7 +1125,7 @@ class AppInstall(SimpleGladeApp):
             search_terms = []
             self.sort_by_ranking = False
             model.set_sort_column_id(COL_NAME, gtk.SORT_ASCENDING)
-            model.set_default_sort_func(None)
+            model.set_default_sort_func(self.menu._name_sort_func)
         self.refilter(terms=search_terms)
         self.setBusy(False)
 
@@ -1247,6 +1252,7 @@ class AppInstall(SimpleGladeApp):
         Show the applications that belong to the selected category and
         restore the previos sorting
         """
+        #print "on_treeview_categories_cursor_changed"
         path = treeview.get_cursor()[0]
         iter = treeview.get_model().get_iter(path)
         (name, item) = treeview.get_model()[iter]
@@ -1256,7 +1262,6 @@ class AppInstall(SimpleGladeApp):
         # get the sorting of the current app store
         old_model = self.treeview_packages.get_model()
         (sort_column, sort_type) = old_model.get_sort_column_id()
-        self.treeview_packages.set_model(item.applications)
         # if we are in search mode, set a default sort function and sort by it
         # if the previous store was sorted by it
         if self.sort_by_ranking:
@@ -1271,11 +1276,25 @@ class AppInstall(SimpleGladeApp):
             if sort_column == None:
                 sort_column = COL_NAME
                 sort_type = gtk.SORT_ASCENDING
-            item.applications.set_default_sort_func(None)
-        item.applications.set_sort_column_id(sort_column,
-                                             sort_type)
+            # for anything but "All" use the sort func that does the
+            # always on top sorting, we don't use it for all because
+            # its a bit slow there
+            if path != (0,):
+                item.applications.set_default_sort_func(self.menu._name_sort_func)
+            else:
+                item.applications.set_default_sort_func(None)
+        else:
+            # this can happen if the user right-clicks on "all"
+            # because we do not have a default sort function then
+            # (for performance reasons)
+            sort_column = -1
+            sort_type = gtk.SORT_ASCENDING
+        item.applications.set_sort_column_id(sort_column, sort_type)
+        # hrm, figure out how to set it into the default sorting mode at
+        # startup, this is certianly not the right solution
+        item.applications.set_sort_column_id(-1, sort_type)
         # filter the apps
-        self.refilter()
+        self.refilter(model=item.applications)
         self.setBusy(False)
 
     def on_treeview_packages_cursor_changed(self, treeview):
