@@ -27,7 +27,7 @@ class MyCache(apt.Cache):
 		return False
 	dependslist = candver.DependsList
 	for dep in dependslist.keys():
-            if dep == "Depends" or dep == "PreDepends":
+            if dep == "Depends" or dep == "PreDepends" or dep == "Recommends":
                 # get the list of each dependency object
                 for depVerList in dependslist[dep]:
                     for z in depVerList:
