@@ -111,6 +111,8 @@ class CoreApplicationMenu(object):
                     item.mime = entry.DesktopEntry.get('MimeType', list=True)
                     item.codecs = entry.DesktopEntry.get("X-AppInstall-Codecs").split(';')
                     item.patentBadness = entry.DesktopEntry.get("X-AppInstall-PatentBadness", type='boolean')
+                    item.onTop = entry.DesktopEntry.get("X-AppInstall-AlwaysOnTop", type='boolean')
+                    
                     # popcon data
                     popcon_str = entry.DesktopEntry.get("X-AppInstall-Popcon")
                     if popcon_str != "":
@@ -190,6 +192,7 @@ class Application(MenuItem):
         # states
         self.popcon = 1            # the raw popcon data
         self.rank = 1              # used by the ranking algo
+        self.onTop = False         # show always on top (regardless of rank/name)
         # licence and support
         self.free = False
         self.licenseUri = None
