@@ -15,17 +15,23 @@ class DialogProprietary(SimpleGladeApp):
                                 path=datadir+"/gnome-app-install.glade",
                                 root="dialog_proprietary",
                                 domain="gnome-app-install")
-        msg = "<b><big>%s</big></b>\n\n%s\n\n%s" % (_("Install software from %s?") % item.channel,
-                                                    _("%s is provided by a third party vendor.") %
-                                                    item.name,
-                                                    _("You need a working internet connection to "
-                                                      " continue."))
+        # Create the text of the dialog
+        if item.isv:
+            vendor = item.isv
+        else:
+            vendor = item.channel
+        header = _("Enable the installation of software "
+                   "from %s?") % vendor
+        body = _("%s is provided by a third party vendor.") % item.name
+        internet = _("You need a working internet connection to continue.")
+        msg = "<b><big>%s</big></b>\n\n%s\n\n%s" % (header, body, internet)
+
         self.dialog_proprietary.set_transient_for(parent)
         self.dialog_proprietary.realize()
         self.dialog_proprietary.window.set_functions(gtk.gdk.FUNC_MOVE)
         self.label_proprietary.set_markup(msg)
         self.item = item
-        self.button_add_channel.set_label(_("_Install"))
+        self.button_add_channel.set_label(_("_Enable"))
 
     def run(self):
         if self.item.licenseUri:
@@ -33,7 +39,7 @@ class DialogProprietary(SimpleGladeApp):
             msg += "\n\n"
             msg += _("The application comes with the following license "
                      "terms and conditions. Click on the "
-                     "'Install' button to accept them:")
+                     "'Enable' button to accept them:")
             self.label_proprietary.set_markup(msg)
             self.tooltips = gtk.Tooltips()
             self.tooltips.set_tip(self.button_add_channel, \
@@ -42,7 +48,6 @@ class DialogProprietary(SimpleGladeApp):
             self.browser.show()
             self.browser.loadUri(self.item.licenseUri)
         else:
-            self.button_add_channel.set_label(_("_Ok"))
             self.browser.hide()
         self.button_add_channel.grab_default()
         return self.dialog_proprietary.run()
@@ -55,7 +60,6 @@ class DialogProprietary(SimpleGladeApp):
         self.browser = BrowserView()
         return self.browser
 
-
 if __name__ == "__main__":
     import sys
 
