@@ -20,6 +20,9 @@ import gdbm
 import gconf
 import errno
 import gettext
+import os
+import os.path
+
 from gettext import gettext as _
 from optparse import OptionParser
 
@@ -192,7 +195,21 @@ class CodecSearchActivationStyle(SearchActivationStyle):
 
     def modifyUserInterface(self, app):
         import gtk
+        import distros
+
         SearchActivationStyle.modifyUserInterface(self, app)
+
+        app.textview_description.show_message("", 
+          _("Some countries allow patents on software, and freely "
+            "redistributable software like Ubuntu cannot pay for patent "
+            "licenses. If you are in "
+            "one of these jurisdictions, you can buy licensed media playback "
+            "plug-ins from the Canonical Store. Otherwise, select a free "
+            "plug-in above to install it."))
+        app.button_help.hide()
+        app.treeview_packages.set_headers_visible(False)
+        app.treeview_packages.column_app_popcon.set_visible(False)
+
         #FIXME: second message needs some love
         app.label_progress.set_markup("<big><b>%s</b></big>\n\n%s" %
                                       (_("Searching for appropriate "
@@ -201,13 +218,32 @@ class CodecSearchActivationStyle(SearchActivationStyle):
                                          "minute or two.")))
         app.hbox_search_show.hide()
         app.button_ok.set_label(_("_Install"))
-        app.window_main.set_title(_("Install multimedia codecs"))
+        app.window_main.set_title(_("Install Media Plug-ins"))
         app.window_main.set_property("default_width", 500)
         app.window_main.set_property("default_height", 400)
         col = app.treeview_packages.get_column(1)
         col.set_title(_("Codec"))
         model = app.treeview_packages.get_model()
         model.set_sort_column_id(2, gtk.SORT_DESCENDING)
+        # add codec link
+        distro = distros.get_distro()
+        (label, url) = distro.get_codec_information_link()
+        if (label is not None) and (url is not None):
+            button = gtk.Button(label)
+            button.uri = url
+            button.connect("clicked", self.uri_clicked)
+            button.show()
+            app.hbox_help.pack_end(button)
+
+    def uri_clicked(self, button):
+        import subprocess
+        for opener in ["gnome-open", "sensible-browser", 
+                       "xdg-open", "x-www-browser"]:
+            for d in os.environ["PATH"].split(":"):
+                if os.path.exists(os.path.join(d,opener)):
+                    print "found ", opener
+                    subprocess.call([opener,button.uri])
+                    return
 
     def menuCacheName(self):
         return "codec_menu.p"
@@ -236,11 +272,11 @@ class CodecSearchActivationStyle(SearchActivationStyle):
 
     def quitHook(self):
        if not self._userapproved:
-               print >>sys.stderr, _("additional codec installation declined")
+               #print >>sys.stderr, _("additional codec installation declined")
                #sys.exit(3)
                sys.exit(4)
        if not self._changessuccessful:
-               print >>sys.stderr, _("additional codec installation failed")
+               #print >>sys.stderr, _("additional codec installation failed")
                sys.exit(2)
 
     def autoClose(self):
@@ -343,6 +379,11 @@ class XULExtensionsActivationStyle(MimeSearchActivationStyle):
         self._string = "application/x-debian-xul-extension-%s" % \
                        options.xul_extensions.lower()
 
+    # all extensions are in universe but are maintained security wise by
+    # the firefox team (see #267392)
+    def isApproved(self, component, package):
+        return True
+
     def quitHook(self):
         if self._changessuccessful:
             print >>sys.stderr, "changed extensions"
@@ -425,7 +466,7 @@ def main():
             app.applyChanges([item], [])
 
     # activation style
-    if sys.argv[0].split("/")[-1] == "gnome-codec-install":
+    if sys.argv[0].split("/")[-1] == "gstreamer-codec-install":
         style = CodecSearchActivationStyle(options, args)
     elif options.mime_type:
         #FIXME: What is an uri, duri?
