@@ -32,6 +32,7 @@ class AppDescView(ReleaseNotesViewer):
         desktop_environment = ""
         icons = []
         homepage = ""
+        style = self.get_style()
 
         if self.menu.itemAvailable(item):
             pkg = self.cache[item.pkgname]
@@ -101,6 +102,15 @@ class AppDescView(ReleaseNotesViewer):
                                      "computer type.") % (item.name, 
                                      self.cache.getArch()))
                     break
+            # check if it comes from a third party repository and
+            # display message then
+            if item.channel:
+                details.append(_("%s is available in the third party software " 
+                                 "channel '%s'. To install it, please "
+                                 "click on the checkbox to activate the "
+                                 "software channel.") % 
+                               (item.name, item.channel))
+
         # mutliple apps per pkg check
         s = ""
         if self.menu.pkg_to_app.has_key(item.name) and \
@@ -164,11 +174,6 @@ class AppDescView(ReleaseNotesViewer):
             buffer.insert_with_tags_by_name(iter, "%s" % item.name, "app-name")
 
         emblems = self.distro.get_app_emblems(item, self.cache)
-        for e in emblems:
-            # Append the emblem text to the description
-            if type(e[1]) == str:
-                clean_desc += "\n%s" % e[1]
-
         if short_desc != "": 
             tag_name = buffer.create_tag("short-desc",
                                          weight=pango.WEIGHT_BOLD)
@@ -185,7 +190,6 @@ class AppDescView(ReleaseNotesViewer):
                 image_emblem.set_pixel_size(16)
                 event = gtk.EventBox()
                 # use the base color of the textview for the image
-                style = self.get_style()
                 # FIXME: send the selected signal from the anchor 
                 #        to the widget
                 for state in [gtk.STATE_NORMAL, gtk.STATE_ACTIVE,
@@ -199,7 +203,7 @@ class AppDescView(ReleaseNotesViewer):
                 buffer.insert(iter, " ")
                 anchor = buffer.create_child_anchor(iter)
                 self.add_child_at_anchor(event,
-                                                              anchor)
+                                         anchor)
                 event.show()
                 image_emblem.show()
         if clean_desc != "": 
@@ -211,6 +215,19 @@ class AppDescView(ReleaseNotesViewer):
         if len(details) > 0:
             for x in details:
                 buffer.insert(iter, "\n%s" % x)
+        # add maintenance status
+        #buffer.insert(iter, " ")
+        #anchor = buffer.create_child_anchor(iter)
+        #foo = gtk.Frame(self.distro.get_maintenance_status(item, self.cache))
+        #foo.show()
+        #self.add_child_at_anchor(foo, anchor)
+        buffer.create_tag("maint-status", 
+                          scale_set=True,
+                          scale=pango.SCALE_SMALL,
+                          foreground="#888")
+        #                  foreground_gdk=style.base[gtk.STATE_INSENSITIVE])
+        m = self.distro.get_maintenance_status(item, self.cache)
+        buffer.insert_with_tags_by_name(iter, "\n%s" % m, "maint-status")
 
     def show_message(self, header, msg):
         """ Show a quick introduction to gnome-app-install 
@@ -218,13 +235,15 @@ class AppDescView(ReleaseNotesViewer):
         buffer = self.get_buffer()
         buffer.set_text("")
         iter = buffer.get_start_iter()
-        tag_header = buffer.create_tag("header",
-                                       scale = pango.SCALE_LARGE,
-                                       weight = pango.WEIGHT_BOLD,
-                                       pixels_above_lines=6)
-
-        buffer.insert_with_tags(iter, "%s\n" % header, 
-                                tag_header)
+        tag_header = buffer.get_tag_table().lookup("header")
+        if not tag_header:
+            tag_header = buffer.create_tag("header",
+                                           scale = pango.SCALE_LARGE,
+                                           weight = pango.WEIGHT_BOLD,
+                                           pixels_above_lines=6)
+        if header:
+            buffer.insert_with_tags(iter, "%s\n" % header, 
+                                    tag_header)
         buffer.insert(iter, msg)
 
     def clear_description(self):
